Learn R Programming

OEFPIL (version 0.1.1)

silicaBerk: Nanoindentation measurements data

Description

Load and depth measured with Berkovich diamond tip on fused silica material. Data contains only unloading part of indentation curve. The relationship between Load (F) and Depth (h) is given by equation \(F = \alpha (h - h_p)^{m}\), where \(h_{p}\) is permanent indentation depth after removal of the load, \(\alpha\) is fitting constant related to the indenter geometry and power law exponent m should be from (1,2) interval.

Usage

silicaBerk

Arguments

Format

The data frame contains two columns:

Depth

nanoindentation depth, in nanometers.

Load

load, in milinewtons.

Examples

Run this code
# NOT RUN {
attach(silicaBerk)
plot(Depth, Load, main = 'Graph of nanoindentation data', xlab = 'Depth (nm)', ylab = 'Load (mN)',
col = 'darkgreen', cex = 1)
# }

Run the code above in your browser using DataLab