Learn R Programming

OEFPIL (version 0.1.1)

vcov.OEFPIL: Covariance matrix from an OEFPIL object

Description

Function for extracting the estimated covariance matrix from an object of class "OEFPIL".

Usage

# S3 method for OEFPIL
vcov(object, ...)

Arguments

object

an object of class "OEFPIL" (a result of a call to OEFPIL).

...

other arguments.

Value

A matrix of the estimated covariances between the parameter estimates from an "OEFPIL" object.

See Also

OEFPIL

Examples

Run this code
# NOT RUN {
##-- Continuing the coef.OEFPIL(.) example:

##Use of vcov function
vcov(st1)

# }

Run the code above in your browser using DataLab