print.OEFPIL: Print function for an object of class 'OEFPIL'
Description
Function prints the information about an object of class "OEFPIL".
Usage
# S3 method for OEFPIL
print(x, ...)
Arguments
x
an object of class "OEFPIL" (a result of a call to OEFPIL).
...
other arguments.
Value
Function prints short summary of "OEFPIL" object into the console. In case of assigning value into the variable, it returns object of class "OEFPIL", which is a list with components defined in OEFPIL.