powered by
Function for extracting the estimated covariance matrix from an object of class "OEFPIL".
"OEFPIL"
# S3 method for OEFPIL vcov(object, ...)
an object of class "OEFPIL" (a result of a call to OEFPIL).
OEFPIL
other arguments.
A matrix of the estimated covariances between the parameter estimates from an "OEFPIL" object.
# NOT RUN { ##-- Continuing the coef.OEFPIL(.) example: ##Use of vcov function vcov(st1) # }
Run the code above in your browser using DataLab